sequencetools.yield_all_set_partitions_of_sequence
==================================================

.. autofunction:: abjad.tools.sequencetools.yield_all_set_partitions_of_sequence.yield_all_set_partitions_of_sequence
